package com.jot.judiciarymobile.activity.ui.causeList;

import android.app.ProgressDialog;
import android.os.Bundle;
import android.text.Editable;
import android.text.TextWatcher;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.view.WindowManager;
import android.widget.AdapterView;
import android.widget.EditText;
import android.widget.ListView;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.fragment.app.Fragment;
import androidx.fragment.app.FragmentManager;
import androidx.fragment.app.FragmentTransaction;

import com.android.volley.Response;
import com.android.volley.VolleyError;
import com.android.volley.VolleyLog;
import com.android.volley.toolbox.JsonArrayRequest;
import com.jot.judiciarymobile.R;
import com.jot.judiciarymobile.config.AppConfig;
import com.jot.judiciarymobile.config.AppController;
import com.jot.judiciarymobile.helper.CaseList;
import com.jot.judiciarymobile.helper.CustomListAdapter;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;

import static android.content.ContentValues.TAG;


public class CaseCauseListFragment extends Fragment {

    TextView empty,SearchDetails;
    EditText inputSearch;
    private ProgressDialog pDialog;
    private ArrayList<CaseList> caseList = new ArrayList<CaseList>();
    private ListView listView;
    private CustomListAdapter adapter;
    public static String URL_SEARCH_CAUSE_LIST;


    public View onCreateView(@NonNull LayoutInflater inflater ,
                             ViewGroup container , Bundle savedInstanceState) {

        View root = inflater.inflate(R.layout.fragment_case_cause_list , container , false);
        getActivity().getWindow().setSoftInputMode(WindowManager.LayoutParams.SOFT_INPUT_STATE_ALWAYS_HIDDEN);



        listView = root.findViewById(R.id.list_cases);
        empty = root.findViewById(android.R.id.empty);
        inputSearch = root.findViewById(R.id.inputSearch);
        SearchDetails = root.findViewById(R.id.SearchDetails);
        adapter = new CustomListAdapter(getActivity() , caseList);
        listView.setEmptyView(empty);
        listView.setAdapter(adapter);


        pDialog = new ProgressDialog(getActivity());
        pDialog.setMessage("Loading...");
        pDialog.show();


        getSearchCase();
        SearchCauseList();

        return root;
    }



    public void getSearchCase(){


        String judge_name = getArguments().getString("judge_name");
        String court_name = getArguments().getString("court_name");
        String date_from = getArguments().getString("date_from");
        String date_to = getArguments().getString("date_to");

        DateFormat input = new SimpleDateFormat("dd-MM-yyyy");
        DateFormat output = new SimpleDateFormat("yyyy-MM-dd");

        Date date1 = null;
        Date date2 = null;

        try {
            date1 = input.parse(date_from);
            date2 = input.parse(date_to);

        } catch (ParseException e) {
            e.printStackTrace();
        }



        if(court_name == null) {
            URL_SEARCH_CAUSE_LIST = AppConfig.URL_SEARCH_CAUSE_LIST_JUDGE + judge_name + "/'" + output.format(date1) + "'/'" + output.format(date2) + "'/";
            SearchDetails.setText("Search results:\nFrom "+date_from+" to "+date_to+"\nBefore: "+judge_name);
        }

        if(judge_name == null) {
            URL_SEARCH_CAUSE_LIST = AppConfig.URL_SEARCH_CAUSE_LIST_COURT +"'" + court_name + "'/'" + output.format(date1) + "'/'" + output.format(date2) + "'/";
            SearchDetails.setText("Search results:\nFrom "+date_from+" to "+date_to+"\n"+court_name);
        }
        // Creating volley request obj
        JsonArrayRequest searchCase = new JsonArrayRequest(URL_SEARCH_CAUSE_LIST ,
                new Response.Listener<JSONArray>() {
                    @Override
                    public void onResponse(JSONArray response) {
                        Log.d(TAG , response.toString());
                        hideDialog();

                        // Parsing json
                        DateFormat input = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss.SSSX");
                        DateFormat output = new SimpleDateFormat("E, MMM dd yyyy");

                        Date date3 = null;

                        for (int i = 0; i < response.length(); i++) {
                            try {


                                JSONObject obj = response.getJSONObject(i);

                                date3 = input.parse(obj.getString("date_of_stage_or_determination"));

                                CaseList cause_list = new CaseList();
                                cause_list.setCourtName(obj.getString("name"));
                                cause_list.setCaseTitle(obj.getString("case_title"));
                                cause_list.setCaseParties((obj.getString("case_parties")));
                                cause_list.setRef_no((obj.getString("case_ref_number")));
                                cause_list.setJudgeName(obj.getString("judge_name"));
                                cause_list.setCourtRoom((obj.getString("court_room_name")));
                                cause_list.setStageName(obj.getString("stage_name_or_last_order"));
                                cause_list.setStageDate(output.format(date3));

                                caseList.add(cause_list);

                            } catch (JSONException e) {
                                e.printStackTrace();
                            } catch (ParseException e) {
                                e.printStackTrace();
                            }

                        }


                        // notifying list adapter about data changes
                        // so that it renders the list view with updated data

                        adapter.notifyDataSetChanged();


                    }
                } , new Response.ErrorListener() {
            @Override
            public void onErrorResponse(VolleyError error) {
                VolleyLog.d(TAG , "Error: " + error.getMessage());
                hideDialog();

            }
        });

        // Adding request to request queue
        AppController.getInstance().addToRequestQueue(searchCase);
    }
    private void SearchCauseList(){
        inputSearch.addTextChangedListener(new TextWatcher() {

            @Override
            public void beforeTextChanged(CharSequence arg0, int arg1, int arg2, int arg3) {
                // TODO Auto-generated method stub
            }

            @Override
            public void onTextChanged(CharSequence cs, int arg1, int arg2, int arg3) {
                // When user changed the Text
                CaseCauseListFragment.this.adapter.getFilter().filter(cs);

            }


            @Override
            public void afterTextChanged(Editable cs) {
                // TODO Auto-generated method stub
                inputSearch.removeTextChangedListener(this);
                inputSearch.addTextChangedListener(this);

                Log.e("Value","After");



            }
        });
    }
    private void showDialog() {
        if (!pDialog.isShowing())
            pDialog.show();
    }
    private void hideDialog() {
        if (pDialog.isShowing())
            pDialog.dismiss();
    }


}
