package com.jot.judiciarymobile.activity.ui.searchCase;

import android.app.AlertDialog;
import android.app.ProgressDialog;
import android.content.Context;
import android.os.Bundle;

import androidx.annotation.NonNull;
import androidx.fragment.app.Fragment;
import androidx.fragment.app.FragmentManager;
import androidx.fragment.app.FragmentTransaction;

import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.view.WindowManager;
import android.widget.ArrayAdapter;
import android.widget.AutoCompleteTextView;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Toast;

import com.android.volley.RequestQueue;
import com.android.volley.Response;
import com.android.volley.VolleyError;
import com.android.volley.toolbox.JsonArrayRequest;
import com.android.volley.toolbox.Volley;
import com.jot.judiciarymobile.R;
import com.jot.judiciarymobile.config.AppConfig;
import com.jot.judiciarymobile.config.AppController;
import com.jot.judiciarymobile.config.InternetStatus;
import com.jot.judiciarymobile.config.Settings;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.util.ArrayList;
import java.util.Calendar;


public class SearchCaseRefFragment extends Fragment {

    private static final String TAG = SearchCaseRefFragment.class.getSimpleName();

    EditText CaseRefNumber;
    ProgressDialog pDialog;
    RequestQueue requestQueue;
    Button SearchButton;
    CaseRefNoInterface cListener;
    public static String SEARCH_CASE;

    public View onCreateView(@NonNull LayoutInflater inflater ,
                             ViewGroup container , Bundle savedInstanceState) {


        View root = inflater.inflate(R.layout.fragment_search_case_ref , container , false);
        getActivity().getWindow().setSoftInputMode(WindowManager.LayoutParams.SOFT_INPUT_STATE_VISIBLE| WindowManager.LayoutParams.SOFT_INPUT_ADJUST_RESIZE);
//        getActivity().setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_PORTRAIT);


        pDialog = new ProgressDialog(getActivity());
        pDialog.setCancelable(false);


        CaseRefNumber = root.findViewById(R.id.CaseRefNumber);
        SearchButton = root.findViewById(R.id.SearchButton);
        requestQueue = Volley.newRequestQueue(getActivity());


        // Register Button Click event
        if (InternetStatus.getInstance(getContext()).isOnline()) {


            SearchButton.setOnClickListener(new View.OnClickListener() {
                public void onClick(View view) {

                    String case_ref_number = CaseRefNumber.getText().toString().trim();

                    if (!case_ref_number.isEmpty()) {


                        SEARCH_CASE = AppConfig.URL_SEARCH_CASE_REF_NUMBER + case_ref_number;

                        pDialog = new ProgressDialog(getActivity());
                        pDialog.setMessage("Loading...");
                        pDialog.show();

                        getCaseDetails();


                    }
                    if (case_ref_number.isEmpty()) {
                        Toast.makeText(getActivity() ,
                                (getResources().getString(R.string.app_search_fields)) , Toast.LENGTH_LONG).show();
                    }

                }


            });

        } // InternetLost Connection

        else {
            noConnection();
        }


        return root;
    }

    @Override
    public void onAttach(@NonNull Context context) {
        super.onAttach(context);
        if (context instanceof SearchCaseRefFragment.CaseRefNoInterface){
            cListener = (SearchCaseRefFragment.CaseRefNoInterface) context;
        }else{
            Log.d(SearchCaseRefFragment.class.getSimpleName(), "Could not cast");
        }
    }
    private void getCaseDetails(){
        // Creating volley request obj
        JsonArrayRequest movieReq = new JsonArrayRequest(SEARCH_CASE ,
                new Response.Listener<JSONArray>() {
                    @Override
                    public void onResponse(JSONArray response) {
                        Log.d(TAG , response.toString());
                        hideDialog();

                        // Parsing json


                        for (int i = 0; i < response.length(); i++) {
                            try {

                                JSONObject obj = response.getJSONObject(i);

                                String Case_Court_Name = obj.getString("name");
                                String Case_Filing_Date = obj.getString("filing_date");
                                String Case_Title = obj.getString("case_title");
                                String Case_Parties = obj.getString("case_parties");
                                String Case_Status = obj.getString("proceeding_outcome");
                                String Case_Ref_Number = obj.getString("case_ref_number");
                                String Case_Judge = obj.getString("judge_name");
                                String Case_Court_Room = obj.getString("court_room_name");
                                String Case_Court_Stage = obj.getString("stage_name_or_last_order");
                                String Case_Court_Date = obj.getString("date_of_stage_or_determination");
                                String Case_Determination = obj.getString("mode_of_determinatin");
                                String Case_Outcome = obj.getString("case_outcome");


                                Bundle bundle = new Bundle();
                                bundle.putString("name" , Case_Court_Name);
                                bundle.putString("filing_date" , Case_Filing_Date);
                                bundle.putString("case_title" , Case_Title);
                                bundle.putString("case_parties" , Case_Parties);
                                bundle.putString("case_ref_number",Case_Ref_Number);
                                bundle.putString("proceeding_outcome" , Case_Status);
                                bundle.putString("judge_name" , Case_Judge);
                                bundle.putString("court_room_name" , Case_Court_Room);
                                bundle.putString("stage_name_or_last_order" , Case_Court_Stage);
                                bundle.putString("date_of_stage_or_determination" , Case_Court_Date);
                                bundle.putString("mode_of_determinatin" , Case_Determination);
                                bundle.putString("case_outcome" , Case_Outcome);

                                cListener.openCaseDetails(bundle);
                                Settings.hideKeyboard(getActivity());

//                                CaseDetailsFragment fragment = new CaseDetailsFragment();
//                                FragmentManager fragmentManager = getParentFragmentManager();
//                                FragmentTransaction fragmentTransaction = fragmentManager.beginTransaction();
//                                fragment.setArguments(bundle);
//                                fragmentTransaction.replace(R.id.nav_host_fragment , fragment , fragment.getTag());
//                                fragmentTransaction.addToBackStack(null);
//                                fragmentTransaction.commit();

                            } catch (JSONException e) {
                                e.printStackTrace();
                            }

                        }


                    }
                } , new Response.ErrorListener() {
            @Override
            public void onErrorResponse(VolleyError error) {

                if (error.getMessage() == null){
                    AlertDialog.Builder builder = new AlertDialog.Builder(getActivity());
                    builder.setTitle("NO CASE FOUND");
                    builder.setMessage("Check all the information provided if there are correct and try again")

                            .setNegativeButton(getResources().getString(R.string.app_button_dismiss), null);
                    builder.show();
                }


                hideDialog();
            }
        });

        // Adding request to request queue
        AppController.getInstance().addToRequestQueue(movieReq);

    }
    private void showDialog() {
        if (!pDialog.isShowing())
            pDialog.show();
    }
    private void hideDialog() {
        if (pDialog.isShowing())
            pDialog.dismiss();
    }
    private void noConnection(){
        Toast.makeText(getActivity(), "Connection lost.. please reconnect", Toast.LENGTH_SHORT).show();
        SearchButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                Toast.makeText(getActivity(), "Connection lost.. please reconnect", Toast.LENGTH_SHORT).show();
            }
        });

    }
    private void noServerConnection(){
        Toast.makeText(getActivity(), "Oops! out of Service Try again later", Toast.LENGTH_SHORT).show();
        SearchButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                Toast.makeText(getActivity(), "Oops! out of Service Try again later", Toast.LENGTH_SHORT).show();

            }
        });

    }
    public interface CaseRefNoInterface{

        void openCaseDetails(Bundle bundle);
    }


}