package com.jot.judiciarymobile.helper;
import android.app.Activity;
import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.Filter;
import android.widget.Filterable;
import android.widget.TextView;
import com.android.volley.toolbox.ImageLoader;
import com.jot.judiciarymobile.R;
import com.jot.judiciarymobile.config.AppController;
import java.util.ArrayList;
import java.util.List;

public class CustomListAdapter extends BaseAdapter implements Filterable {
    private Activity activity;
    private LayoutInflater inflater;
    private static List<CaseList> allItems;
    private static List<CaseList> caseItems;
    ImageLoader imageLoader = AppController.getInstance().getImageLoader();


    public CustomListAdapter(Activity activity, List<CaseList> caseItems) {
        this.activity = activity;
        this.allItems = caseItems;
        this.caseItems = caseItems;
    }

    @Override
    public int getCount() {
        return caseItems.size();
    }

    @Override
    public Object getItem(int location) {
        return caseItems.get(location);
    }

    @Override
    public long getItemId(int position) {
        return position;
    }

    @Override
    public View getView(int position, View convertView, ViewGroup parent) {

        if (inflater == null)
            inflater = (LayoutInflater) activity
                    .getSystemService(Context.LAYOUT_INFLATER_SERVICE);
        if (convertView == null)
            convertView = inflater.inflate(R.layout.caselist_row, null);

        if (imageLoader == null)
            imageLoader = AppController.getInstance().getImageLoader();

        TextView court_name = (TextView) convertView.findViewById(R.id.CourtName);
        TextView case_title = (TextView) convertView.findViewById(R.id.CaseTitle);
        TextView case_parties = (TextView) convertView.findViewById(R.id.CaseParties);
        TextView judge_name = (TextView) convertView.findViewById(R.id.Judge);
        TextView court_room_name = (TextView) convertView.findViewById(R.id.Room);
        TextView stage_name = (TextView) convertView.findViewById(R.id.StageName);
        TextView date_of_stage = (TextView) convertView.findViewById(R.id.date_of_stage);
        TextView ref_no = (TextView) convertView.findViewById(R.id.CaseRefNo);

        // getting movie data for the row
        CaseList m = caseItems.get(position);

        court_name.setText(m.getCourtName());
        case_title.setText(String.valueOf(m.getCaseTitle()));
        case_parties.setText(String.valueOf(m.getCaseParties()));
        judge_name.setText(String.valueOf(m.getJudgeName()));
        court_room_name.setText(String.valueOf(m.getCourtRoom()));
        stage_name.setText(m.getStageName());
        date_of_stage.setText(String.valueOf(m.getStageDate()));
        ref_no.setText(String.valueOf(m.getRef_no()));

        return convertView;
    }

    @Override
    public Filter getFilter() {
        return new Filter() {
            @SuppressWarnings("unchecked")
            @Override
            protected void publishResults(CharSequence constraint, final FilterResults results) {
                if (results.count > 0) {
                    caseItems = (List<CaseList>) results.values;
                    notifyDataSetChanged();
                }
            }

            @Override
            protected FilterResults performFiltering(final CharSequence constraint) {
                final List<CaseList> filteredResults = getFilteredResults(constraint);
                final FilterResults results = new FilterResults();
                results.values = filteredResults;
                results.count = filteredResults.size();
                return results;
            }
        };
    }

    private List<CaseList> getFilteredResults(CharSequence cs) {
        String searchString = String.valueOf(cs).toUpperCase();
        if (searchString.isEmpty()) return allItems;
        List<CaseList> output = new ArrayList<>();

        for (CaseList history : allItems) {

            String toCaseTitle = history.getCaseTitle();
            String toCaseParties = history.getCaseParties();
            String toRef_no = history.getRef_no();

            if (toCaseTitle.contains(",")) toCaseTitle = toCaseTitle.replace(",", "");

            if (toCaseTitle.toUpperCase().contains(searchString)) {
                output.add(history);
            }
            else if (toCaseParties.toUpperCase().contains(searchString)) {
                output.add(history);
            }

            else if (toRef_no.toUpperCase().contains(searchString)){
                output.add(history);
            }

        }
        return output;
    }
}

